#!/usr/bin/env python3
import json
import sys
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.dates as mdates
import arrow

all_cc = set()

out = {}
with open("countries.netdiff.v4.jsonf") as inf:
    for line in inf:
        d = json.loads( line, encoding='utf-8' )
        ts = d['ts']
        out[ ts ] = d['per_cc']
        for cc in d['per_cc'].keys():
            all_cc.add( cc )

cc_sorted = sorted( all_cc )
ts_sorted = sorted( out.keys() )

keys = ['asns_dropped_pfxes', 'asns_added_pfxes', 'asns_changed_pfxes', 'asns_any']

#### now do 1 per country, or a special aggregate
if len( sys.argv ) > 1:
    pass

else:
    # one per country
    for cc in cc_sorted:
        print("creating output for each country: %s" % cc )
        x = []
        y = {key: [] for (key) in keys}

        for ts in ts_sorted:
            x.append( arrow.get( ts, tz='UTC' ).datetime )
            for key in keys:
                if cc in out[ ts ] and out[ ts ][ cc ][ key ]:
                    y[ key ].append( out[ts][cc][key] )
                else:
                    y[ key ].append( 0 )

        fig,axs = plt.subplots(nrows=4, ncols=1, figsize=[40,15])
        fig.suptitle('BGP prefix changes (2020)', fontsize=20)
        #plt.ylabel('Volume')
        #plt.xlabel('Time')
        for ax in axs:
               ax.xaxis.set_major_locator( mdates.WeekdayLocator() )
               ax.xaxis.set_major_formatter( mdates.DateFormatter('%m-%d') )
               ax.xaxis.set_minor_locator( mdates.DayLocator() )
        for idx,key in enumerate( keys ):
            #axs[ idx ].plot(x, y[key], label=[key] )
            axs[ idx ].step(x, y[key], label=[key], where='post' )
            axs[ idx ].set_ylabel( key )
            axs[ idx ].grid(axis='x')
        #for pkey in pkeys:
        #    if key == 'changed_pfxes':
        #        ax2.plot(x, y[pkey], label=pkey, c='green')
        #    else:
        #        ax.plot(x, y[pkey], label=pkey)
        fig.autofmt_xdate()
        plt.tight_layout()
        fig.savefig("./countries/%s.pdf" % cc, dpi=600 )
        plt.close()
        #ax.set_yscale('log')
        #ax2.set_yscale('log')
        #fig.savefig("orig_changes.log.png")
'''
        fig,ax = plt.subplots()
        ax2 = ax.twinx()
        ax.xaxis.set_major_locator( mdates.WeekdayLocator() )
        ax.xaxis.set_major_formatter( mdates.DateFormatter('%Y-%m-%d') )
        ax.xaxis.set_minor_locator( mdates.DayLocator() )
        fig.suptitle('ASNs with BGP prefix changes', fontsize=20)
        plt.ylabel('Volume')
        plt.xlabel('Time')
        for akey in akeys:
            if key == 'asns_changed_pfxes':
                ax2.plot(x, y[akey], label=akey, c='green')
            else:
                ax.plot(x, y[akey], label=akey)
        plt.grid(axis='x')
        fig.legend()
        fig.autofmt_xdate()
        fig.savefig("./countries/%s.asn.png" % cc )
        plt.close()
        #ax.set_yscale('log')
        #ax2.set_yscale('log')
        #fig.savefig("nets_w_orig_changes.log.png")
'''
